NOID-mint Python Package

## Installation
```
pip install noid-mint
```
or
```
git clone git@github.com:vt-digital-libraries-platform/NOID-mint.git
python setup.py install
```

## Usage
* Generate noid
```
noid -f local.yml
```

## Testing
```
nosetests
```

## Authors
* Virginia Tech Libraries - Digital Libraries Development developers
	* [Yinlin Chen](https://github.com/yinlinchen)
	* [Tingting Jiang](https://github.com/tingtingjh)
	* [Lee Hunter](https://github.com/whunter)

See also the list of [contributors](https://github.com/vt-digital-libraries-platform/NOID-mint/graphs/contributors) who participated in this project.

## Thanks
This tool was heavily influenced from [pynoid](https://github.com/no-reply/pynoid)